﻿using HeuristicLab.Common;
using HeuristicLab.Encodings.SymbolicExpressionTreeEncoding;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;

namespace HeuristicLab.Problems.Robocode {
  [StorableClass]
  public class ElseStatement : CodeNode {
    public override int MinimumArity { get { return 1; } }
    public override int MaximumArity { get { return 1; } }

    [Storable]
    public override string Prefix { get; set; }

    [Storable]
    public override string Suffix { get; set; }

    [StorableConstructor]
    private ElseStatement(bool deserializing) : base(deserializing) { }
    private ElseStatement(ElseStatement original, Cloner cloner)
      : base(original, cloner) {

    }

    public ElseStatement()
      : base("ElseStatement", "An ElseStatement.") {
      this.Prefix = "else";
      this.Suffix = "";
    }

    public override IDeepCloneable Clone(Cloner cloner) {
      return new ElseStatement(this, cloner);
    }

    public override string Interpret(ISymbolicExpressionTreeNode node, System.Collections.Generic.IEnumerable<ISymbolicExpressionTreeNode> children) {
      string result = "";
      foreach (ISymbolicExpressionTreeNode c in children)
        result += "\r\n" + ((CodeNode)c.Symbol).Interpret(c, c.Subtrees);
      return (result == "") ? "" : this.Prefix + "\r\n" + result + "\r\n" + this.Suffix;
    }
  }
}
